{% load i18n %}

<p>{% blocktrans trimmed %}
    After you submitted your order, we will redirect you to a payment partner to complete your payment.
    You will then be redirected back here to get your tickets.
{% endblocktrans %}</p>
